@@ -34,7 +34,7 @@ __all__ = ['Label']
 import pygame
 
 from pygame_menu.utils import assert_color, is_callable, warn
-from pygame_menu.widgets.core import Widget
+from pygame_menu.widgets.core.widget import Widget
 
 from pygame_menu._types import Any, CallbackType, List, Union, Tuple, Optional, \
     ColorType, ColorInputType, EventVectorType, Callable
